/*****************************************************************************
 * FIPS140-2_HMAC_BF70x.h
 *****************************************************************************/

#ifndef __FIPS140_2_HMAC_BF70X_H__
#define __FIPS140_2_HMAC_BF70X_H__


typedef enum
{
	SHA1=1,
	SHA224,
	SHA256
} shaVer;

#define SA_CMD0_OPCODE_HASH 0x3
#define SA_CMD0_DIR_IN 0x1
#define SA_CMD0_PAD_ZERO 0x3
#define SA_CMD0_CIPHER_NULL 0xf
#define SA_CMD0_HASH_SHA1  0x1
#define SA_CMD0_DIGEST_SHA1 0x5
#define SA_CMD0_HASHSRC_NOLOAD   0x3
#define SA_CMD0_HASHSRC_FRMSTATE 0x2
#define SA_CMD0_HASHSRC_FRMSA    0x0
#define SA_CMD0_SVHASH_YES 0x1

#define SA_CMD1_CPYDIGEST 0x1
#define SA_CMD1_CPYPAD    0x1
#define SA_CMD1_HMAC      0x1

#define CTRL_STAT_HASH_FINAL 1


/* structure definition for Command and Result Descriptor */
typedef struct{
  unsigned long CTRL_STAT;
  unsigned long SRC_ADDR;
  unsigned long DEST_ADDR;
  unsigned long SA_ADDR;
  unsigned long SA_STATE_ADDR;
  unsigned long ARC4_STATE_ADDR;
  unsigned long USERID;
  unsigned long LENGTH;
} cd_t, rd_t;


/* structure definition for Security Association (SA) Record  (Table 3.25 from prog manual) */
typedef struct{
  unsigned long CMD_0;
  unsigned long CMD_1;
  unsigned long KEY_0;
  unsigned long KEY_1;
  unsigned long KEY_2;
  unsigned long KEY_3;
  unsigned long KEY_4;
  unsigned long KEY_5;
  unsigned long KEY_6;
  unsigned long KEY_7;
  unsigned long IDIGEST_0;
  unsigned long IDIGEST_1;
  unsigned long IDIGEST_2;
  unsigned long IDIGEST_3;
  unsigned long IDIGEST_4;
  unsigned long IDIGEST_5;
  unsigned long IDIGEST_6;
  unsigned long IDIGEST_7;
  unsigned long ODIGEST_0;
  unsigned long ODIGEST_1;
  unsigned long ODIGEST_2;
  unsigned long ODIGEST_3;
  unsigned long ODIGEST_4;
  unsigned long ODIGEST_5;
  unsigned long ODIGEST_6;
  unsigned long ODIGEST_7;
  unsigned long SPI;
  unsigned long SEQNUM_0;
  unsigned long SEQNUM_1;
  unsigned long NONCE;
} sa_t;


/* structure definition for Security Association (SA) State Record  */
typedef struct{
  unsigned long STATE_IV_0;
  unsigned long STATE_IV_1;
  unsigned long STATE_IV_2;
  unsigned long STATE_IV_3;
  unsigned long STATE_BYTE_CNT_0;
  unsigned long STATE_BYTE_CNT_1;
  unsigned long STATE_IDIGEST_0;
  unsigned long STATE_IDIGEST_1;
  unsigned long STATE_IDIGEST_2;
  unsigned long STATE_IDIGEST_3;
  unsigned long STATE_IDIGEST_4;
  unsigned long STATE_IDIGEST_5;
  unsigned long STATE_IDIGEST_6;
  unsigned long STATE_IDIGEST_7;
} state_t;


#endif /* __FIPS140_2_HMAC_BF70X_H__ */
